Short Cuts
==========

This is a list of specific words and xx together with links to tutorials and FAQ sections containing information about these

.. glossary::

    Masking
        Masking out specific points can be done by following the general procedure as explained in ":ref:`MaskFAQ`".
